==> pytest-ansible-4.0.0.tar.gz: pytest-ansible-4.0.0/tests/integration/test_molecule.py <==
"""Tests specific to the molecule plugin functionality."""

from __future__ import annotations

import os
import subprocess
import sys
from typing import TYPE_CHECKING

import pytest

if TYPE_CHECKING:
    from pytest_ansible.molecule import MoleculeScenario


def test_molecule_collect() -> None:
    """Test pytest collection of molecule scenarios."""
    try:
        proc = subprocess.run(
            "pytest --molecule --collect-only",
            capture_output=True,
            shell=True,
            check=True,
            text=True,
        )
    except subprocess.CalledProcessError as exc:
        pytest.fail(exc.stderr)

    assert proc.returncode == 0
    assert "test[delegated]" in proc.stdout


def test_molecule_disabled() -> None:
    """Ensure the lack of --molecule disables molecule support."""

    proc = subprocess.run(
        f"{sys.executable} -m pytest tests/fixtures/molecule/default/molecule.yml",
        capture_output=True,
        check=False,
        env={"PATH": os.environ["PATH"]},
        shell=True,
        text=True,
    )
    assert proc.returncode == 4
    assert "ERROR: found no collectors" in proc.stdout


def test_molecule_runtest() -> None:
    """Test running the molecule scenarion via pytest."""

    proc = subprocess.run(
        f"{sys.executable} -m pytest --molecule tests/fixtures/molecule/default/molecule.yml",
        capture_output=True,
        check=True,
        env={"PATH": os.environ["PATH"]},
        shell=True,
        text=True,
    )
    assert proc.returncode == 0
    assert "collected 1 item" in proc.stdout
    assert "tests/fixtures/molecule/default/molecule.yml::test " in proc.stdout
    assert "1 passed" in proc.stdout


def test_molecule_fixture(molecule_scenario: MoleculeScenario) -> None:
    """Test the scenario fixture.

    :param molecule_scenario: One scenario
    """
    assert molecule_scenario.test_id in ["fixtures-default", "extensions-default"]
    assert molecule_scenario.name == "default"
    molecule_scenario.test()

==> pytest-ansible-4.1.1.tar.gz: pytest-ansible-4.1.1/tests/integration/test_molecule.py <==
"""Tests specific to the molecule plugin functionality."""

from __future__ import annotations

import os
import subprocess
import sys

from typing import TYPE_CHECKING

import pytest


if TYPE_CHECKING:
    from pytest_ansible.molecule import MoleculeScenario


def test_molecule_collect() -> None:
    """Test pytest collection of molecule scenarios."""
    try:
        proc = subprocess.run(
            "pytest --molecule --collect-only",
            capture_output=True,
            shell=True,
            check=True,
            text=True,
        )
    except subprocess.CalledProcessError as exc:
        pytest.fail(exc.stderr)

    assert proc.returncode == 0
    assert "test[default]" in proc.stdout


def test_molecule_disabled() -> None:
    """Ensure the lack of --molecule disables molecule support."""
    proc = subprocess.run(
        f"{sys.executable} -m pytest tests/fixtures/molecule/default/molecule.yml",
        capture_output=True,
        check=False,
        env={"PATH": os.environ["PATH"]},
        shell=True,
        text=True,
    )
    assert proc.returncode == 4
    assert "ERROR: found no collectors" in proc.stdout


def test_molecule_runtest() -> None:
    """Test running the molecule scenario via pytest."""
    try:
        proc = subprocess.run(
            f"{sys.executable} -m pytest --molecule tests/fixtures/molecule/default/molecule.yml",
            capture_output=True,
            check=True,
            env={"PATH": os.environ["PATH"]},
            shell=True,
            text=True,
        )
        assert proc.returncode == 0
        assert "collected 1 item" in proc.stdout
        assert "tests/fixtures/molecule/default/molecule.yml::test " in proc.stdout
        assert "1 passed" in proc.stdout

    except subprocess.CalledProcessError as exc:
        print(exc.stdout)
        print(exc.stderr)


def test_molecule_fixture(molecule_scenario: MoleculeScenario) -> None:
    """Test the scenario fixture.

    :param molecule_scenario: One scenario
    """
    assert molecule_scenario.test_id in ["fixtures-default", "extensions-default"]
    assert molecule_scenario.name == "default"
    molecule_scenario.test()
